'use client'
import React, {useContext} from 'react';
import {useRouter} from 'next/navigation';
import {AppContext} from '@/context/AppContext';
import {NavigationBtn} from '@/components/NavigationBtn';
import {ServerSelector} from '@/features/servers/components';
import {useSso} from '@/features/auth/hooks';
import {useSessionStorage} from '@/hooks';


export function Menu() {
    const {currentServer, currentVersion} = useContext(AppContext);
    const route = useRouter();
    const {isLoading, loginUrl, ssoSupported} = useSso();
    const {storeSsoState} = useSessionStorage();

    const handleLoad = () => {
        route.push(`/${currentVersion}?target_server=${currentServer}`);
    }

    const handleSsoLogin = () => {
        const url = new URL(loginUrl);
        const state = url.searchParams.get('state');
        storeSsoState(state);
        route.push(loginUrl);
    }

    const noServerAndVersionSelected = !currentVersion || !currentServer;

    return (
        <div className="w-200 mx-auto flex items-center gap-6">
            <ServerSelector />

            <NavigationBtn
                value="Login"
                disabled={noServerAndVersionSelected}
                handleClick={handleLoad}
                color="blue"
                className="w-full"
            />

            {/*<NavigationBtn
                value="SSO Login"
                disabled={isLoading || !ssoSupported}
                handleClick={handleSsoLogin}
                color="gray"
                className="w-full"
            />*/}
        </div>
    );
}
