'use client'
import {STORAGE_KEYS, nextSessionStorage} from '@/utils';
import {useContext} from 'react';
import {AppContext} from '@/context/AppContext';

export function useSessionStorage() {
    const {currentServer} = useContext(AppContext);

    function formatKey(key) {
        return `${currentServer}:${key}`;
    }

    const storedSelectedServer = nextSessionStorage.getItem(STORAGE_KEYS.PORTAL_SELECTED_SERVER);
    const storeSelectedServer = (val) => nextSessionStorage.setItem(STORAGE_KEYS.PORTAL_SELECTED_SERVER, val);
    const storedSelectedSiteWiseVersion = nextSessionStorage.getItem(STORAGE_KEYS.PORTAL_SELECTED_SW_VERSION);
    const storeSelectedSiteWiseVersion = (val) => nextSessionStorage.setItem(STORAGE_KEYS.PORTAL_SELECTED_SW_VERSION, val);
    const storedSsoState = nextSessionStorage.getItem(STORAGE_KEYS.PORTAL_SSO_STATE);
    const storeSsoState = (val) => nextSessionStorage.setItem(STORAGE_KEYS.PORTAL_SSO_STATE, val);
    const removeSsoState = () => nextSessionStorage.removeItem(STORAGE_KEYS.PORTAL_SSO_STATE);

    const storeAccessToken = (val) => nextSessionStorage.setItem(formatKey(STORAGE_KEYS.USER_TOKEN), val);
    const removeAccessToken = () => nextSessionStorage.removeItem(formatKey(STORAGE_KEYS.USER_TOKEN));
    const storeRefreshToken = (val) => nextSessionStorage.setItem(formatKey(STORAGE_KEYS.USER_REFRESH_TOKEN), val);
    const removeRefreshToken = () => nextSessionStorage.removeItem(formatKey(STORAGE_KEYS.USER_REFRESH_TOKEN));
    const storeUserEmail = (val) => nextSessionStorage.setItem(formatKey(STORAGE_KEYS.USER_EMAIL), val);
    const removeUserEmail = () => nextSessionStorage.removeItem(formatKey(STORAGE_KEYS.USER_EMAIL));

    const clearSsoDataStorage = () => {
        removeUserEmail();
        removeRefreshToken();
        removeAccessToken();
    };

    const clearSessionStorage = () => nextSessionStorage.clear();


    return {
        clearSsoDataStorage,
        storeAccessToken,
        removeAccessToken,
        storeRefreshToken,
        removeRefreshToken,
        storeUserEmail,
        removeUserEmail,
        storedSsoState,
        storeSsoState,
        removeSsoState,
        storedSelectedServer,
        storeSelectedServer,
        storedSelectedSiteWiseVersion,
        storeSelectedSiteWiseVersion,
        clearSessionStorage,
    }
}
